@@ -144,6 +144,13 @@ int ipkg_cmd_exec(ipkg_cmd_t *cmd, ipkg_conf_t *conf, int argc, const char **arg
 	int result;
 	p_userdata = userdata;
 	result = (cmd->fun)(conf, argc, argv);
+        if ( result == 0 ) {
+           ipkg_message(conf, IPKG_NOTICE, "Successfully done.\n");
+        } else {
+           ipkg_message(conf, IPKG_NOTICE, "Return value != 0.\n");
+           ipkg_message(conf, IPKG_NOTICE, "Please file a bug in bugzilla. Return code was %d.\n",result);
+        }
+   
 	p_userdata = NULL;
 	return result;
 }
@@ -310,7 +317,7 @@ int ipkg_configure_packages(ipkg_conf_t *conf, regex_t *re)
      pkg_t *pkg;
 
      ipkg_message(conf, IPKG_INFO,
-		  "configuring unpacked packages\n");
+		  "Configuring unpacked packages\n");
      fflush( stdout );
 
      all = pkg_vec_alloc();
@@ -323,8 +330,8 @@ int ipkg_configure_packages(ipkg_conf_t *conf, regex_t *re)
 	       continue;
 
 	  if (pkg->state_status == SS_UNPACKED) {
-	       ipkg_message(conf, IPKG_INFO,
-			    "  configuring %s\n", pkg->name);
+	       ipkg_message(conf, IPKG_NOTICE,
+			    "Configuring %s\n", pkg->name);
 	       fflush( stdout );
 	       if (ipkg_configure(conf, pkg) == 0) {
 		    pkg->state_status = SS_INSTALLED;
@@ -655,6 +662,8 @@ static int ipkg_configure_cmd(ipkg_conf_t *conf, int argc, char **argv)
 	  err = ipkg_configure_packages (conf, NULL);
      }
 
+     write_status_files_if_changed(conf);
+
      return err;
 }
 
